# © 2019 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import _, fields, models
from odoo.exceptions import UserError


class FinancialContract(models.Model):
    _name = "financial.contract"
    _inherit = ["mail.thread", "mail.activity.mixin"]
    _description = "Financial Contract"
    _order = "create_date"
    _check_company_auto = True
    _rec_names_search = ["name", "partner_id.name", "partner_id.member_number"]

    name = fields.Char("Numéro", required=True)
    partner_id = fields.Many2one(
        comodel_name="res.partner",
        string="Coopérative",
        domain="[('is_cooperative', '=', True)]",
        tracking=1,
        required=True,
        index=True,
    )
    state = fields.Selection(
        [
            ("init", "Initialisation"),
            ("running", "En cours"),
            ("done", "Terminé"),
            ("cancel", "Annulé"),
        ],
        string="Statut",
        tracking=1,
        default="init",
    )
    active = fields.Boolean(
        default=True,
        tracking=1,
    )
    description = fields.Text("Description du projet")
    company_id = fields.Many2one(
        comodel_name="res.company", required=True, default=lambda self: self.env.company
    )
    currency_id = fields.Many2one(
        comodel_name="res.currency", related="company_id.currency_id"
    )
    condition_contract_ids = fields.One2many(
        "financial.condition.contract",
        string="Conditions",
        inverse_name="contract_id",
        domain="[('contract_id','=','active_id')]",
    )

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD (Override ORM)
    # ------------------------------------------------------
    def unlink(self):
        """
        Restrict contract deletion depending on state
        """
        for contract in self:
            if contract.state != "init":
                raise UserError(
                    _("Seuls les deals à l'état Projet peuvent être supprimés")
                )
        return super().unlink()
